@@ -27,7 +27,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #define GNOME_DESKTOP_USE_UNSTABLE_API
-#include <libgnomeui/gnome-desktop-thumbnail.h>
+#include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
 #ifdef HAVE_CHEESE
 #include <cheese-avatar-chooser.h>
@@ -186,6 +186,10 @@ update_preview (GtkFileChooser               *chooser,
                                                                                      mime_type);
                 }
 
+                gtk_dialog_set_response_sensitive (GTK_DIALOG (chooser),
+                                                   GTK_RESPONSE_ACCEPT,
+                                                   (pixbuf != NULL));
+
                 if (pixbuf != NULL) {
                         gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
                         g_object_unref (pixbuf);
@@ -371,11 +375,13 @@ setup_photo_popup (UmPhotoDialog *um)
         GDir *dir;
         const char *face;
         GError *error;
+        gboolean none_item_shown;
 
         menu = gtk_menu_new ();
 
         x = 0;
         y = 0;
+        none_item_shown = FALSE;
 
         error = NULL;
         dir = g_dir_open (DATADIR "/pixmaps/faces", 0, &error);
@@ -415,8 +421,20 @@ setup_photo_popup (UmPhotoDialog *um)
         g_signal_connect (G_OBJECT (menuitem), "activate",
                           G_CALLBACK (none_icon_selected), um);
         gtk_widget_show (menuitem);
+        none_item_shown = TRUE;
         y++;
 
+skip_faces:
+	if (!none_item_shown) {
+		menuitem = gtk_menu_item_new_with_label (_("Disable image"));
+		gtk_menu_attach (GTK_MENU (menu), GTK_WIDGET (menuitem),
+				 0, ROW_SPAN - 1, y, y + 1);
+		g_signal_connect (G_OBJECT (menuitem), "activate",
+				  G_CALLBACK (none_icon_selected), um);
+		gtk_widget_show (menuitem);
+		y++;
+	}
+
         /* Separator */
         menuitem = gtk_separator_menu_item_new ();
         gtk_menu_attach (GTK_MENU (menu), GTK_WIDGET (menuitem),
@@ -425,8 +443,6 @@ setup_photo_popup (UmPhotoDialog *um)
 
         y++;
 
-skip_faces:
-
 #ifdef HAVE_CHEESE
         um->take_photo_menuitem = gtk_menu_item_new_with_label (_("Take a photo..."));
         gtk_menu_attach (GTK_MENU (menu), GTK_WIDGET (um->take_photo_menuitem),
@@ -501,21 +517,18 @@ popup_button_draw (GtkWidget      *widget,
                    cairo_t        *cr,
                    UmPhotoDialog  *um)
 {
-        GtkAllocation allocation;
-
-        if (gtk_widget_get_state (widget) != GTK_STATE_PRELIGHT &&
-            !gtk_widget_is_focus (gtk_widget_get_parent (widget))) {
+        if (gtk_widget_get_state (gtk_bin_get_child (GTK_BIN (widget))) != GTK_STATE_PRELIGHT &&
+            !gtk_widget_is_focus (widget)) {
                 return;
         }
 
-        gtk_widget_get_allocation (widget, &allocation);
         gtk_paint_expander (gtk_widget_get_style (widget),
                             cr,
                             gtk_widget_get_state (widget),
                             widget,
                             NULL,
-                            allocation.x + allocation.width,
-                            allocation.y + allocation.height,
+                            gtk_widget_get_allocated_width (widget) - 12,
+                            gtk_widget_get_allocated_height (widget) - 12,
                             GTK_EXPANDER_EXPANDED);
 }
 
@@ -545,7 +558,7 @@ um_photo_dialog_new (GtkWidget *button)
                           G_CALLBACK (on_popup_button_button_pressed), um);
         g_signal_connect (button, "notify::is-focus",
                           G_CALLBACK (popup_button_focus_changed), um);
-        g_signal_connect_after (gtk_bin_get_child (GTK_BIN (button)), "draw",
+        g_signal_connect_after (button, "draw",
                                 G_CALLBACK (popup_button_draw), um);
 
         g_signal_connect (um->photo_popup, "unmap",
